import Command from '@eo-cli/command';
import Package from '@eo-cli/package';

declare enum TEMPLATE_TYPE_ENUM {
    normal = 1,
    custom = 2
}
interface Template {
    name: string;
    ejsProjectName?: string;
    npmName: string;
    version: string;
    ejsProjectVersion?: string;
    type?: TEMPLATE_TYPE_ENUM;
    installCommand: string;
}
type Templates = Template[];

/**
 * @description init 命令
 *
 * 注意：
 * 1. 命令行参数不传的话为 undefined，需要转为对应类型见 line:13/line:14
 */
declare class InitCommand extends Command {
    projectName: string;
    force: boolean;
    projectTemplates: Templates;
    inquirerResult: Record<string, any> | undefined;
    selectTemplate: Template;
    cachepackageInstance: Package;
    init(): void;
    /**
     * @description init exec 执行逻辑
     * 1. 准备阶段
     * 2. 下载模版
     * 3. 按装模版
     */
    exec(): Promise<void>;
    /**
     * @description 准备阶段逻辑
     * 1. 判断当前目录是否不为空
     * 2. 是否启动强制更新
     * 4. 创建项目或者组件
     * 3. 获取项目信息
     */
    prepare(): Promise<Record<string, any> | undefined>;
    /**
     * @description 判断当前目录是否不为空
     * @param localPath
     * @returns
     */
    isLocalPathDirNotEmpty(localPath: string): boolean;
    /**
     * @description 获取用户命令行交互信息
     * 1. 创建项目或者组件
     * 2. 获取项目信息
     * @returns
     */
    getInquirerResult(): Promise<Record<string, any>>;
    /**
     * @description 判断 projectname 是否合规
     * @param input
     * @returns
     */
    isProjectNameVaild(input: string): boolean;
    /**
     * @description 注入 ejs 模版需要的变量
     * @param inquirerResult
     * @returns
     */
    hydrateEjsVariables(inquirerResult: Record<string, any>): Record<string, any>;
    /**
     * @description 下载项目模版
     */
    downloadProjectTemplate(): Promise<void>;
    /**
     * @description 创建命令行交互需要的模版列表数据
     */
    createProjectTemplateChoices(): {
        name: string;
        value: string;
    }[];
    /**
     * @description 安装项目模版
     */
    installProjectTemplate(): Promise<void>;
    installNormalTemplate(): Promise<void>;
    checkPackageManager(_command: string): boolean;
    execCommand(_command: string, errorMessage: string, successMessage: string): Promise<void>;
    ejsRender(ignore?: string[]): Promise<void>;
    installCustomTemplate(): Promise<void>;
}
/**
 * @description init 命令执行逻辑
 * @param options [projectName: string, options: Record<string, any>, CommandInstance]
 * @returns
 */
declare function init(options: any[]): InitCommand;

export { InitCommand, init as default };
